@@ -38,7 +38,8 @@ void *OPENSSL_malloc(size_t);
 void OPENSSL_free(void *);
 
 
-/* Signature changed significantly in 1.1.0, only expose there for sanity */
+/* Signature is significantly different in LibreSSL, so expose via different
+   symbol name */
 int Cryptography_CRYPTO_set_mem_functions(
     void *(*)(size_t, const char *, int),
     void *(*)(void *, size_t, const char *, int),
@@ -76,12 +77,12 @@ CUSTOMIZATIONS = """
 
 #if CRYPTOGRAPHY_IS_LIBRESSL
 static const long Cryptography_HAS_OPENSSL_CLEANUP = 0;
-
 void (*OPENSSL_cleanup)(void) = NULL;
+#else
+static const long Cryptography_HAS_OPENSSL_CLEANUP = 1;
+#endif
 
-/* This function has a significantly different signature pre-1.1.0. since it is
- * for testing only, we don't bother to expose it on older OpenSSLs.
- */
+#if CRYPTOGRAPHY_IS_LIBRESSL || CRYPTOGRAPHY_IS_BORINGSSL
 static const long Cryptography_HAS_MEM_FUNCTIONS = 0;
 int (*Cryptography_CRYPTO_set_mem_functions)(
     void *(*)(size_t, const char *, int),
@@ -89,7 +90,6 @@ int (*Cryptography_CRYPTO_set_mem_functions)(
     void (*)(void *, const char *, int)) = NULL;
 
 #else
-static const long Cryptography_HAS_OPENSSL_CLEANUP = 1;
 static const long Cryptography_HAS_MEM_FUNCTIONS = 1;
 
 int Cryptography_CRYPTO_set_mem_functions(
